diff --git a/ProfileInterface.cpp b/ProfileInterface.cpp
index 231598c..cdbb667 100644
--- a/ProfileInterface.cpp
+++ b/ProfileInterface.cpp
@@ -1102,7 +1102,7 @@ void ProfileInterface::deleteSelected()
}
if (selectedWidgts != 0)
{
- QMessageBox::warning(this, tr("Remove selected"), tr("Failed at remove the complete selected Snapmatic pictures and/or Savegame files"));
+ QMessageBox::warning(this, tr("Remove selected"), tr("Failed to remove all selected Snapmatic pictures and/or Savegame files"));
}
}
}
diff --git a/SavegameDialog.cpp b/SavegameDialog.cpp
index c244ed0..302b92d 100644
--- a/SavegameDialog.cpp
+++ b/SavegameDialog.cpp
@@ -35,10 +35,21 @@ SavegameDialog::SavegameDialog(QWidget *parent) :
ui->cmdClose->setFocus();
savegameLabStr = ui->labSavegameText->text();
+ // Set Icon for Close Button
if (QIcon::hasThemeIcon("dialog-close"))
{
ui->cmdClose->setIcon(QIcon::fromTheme("dialog-close"));
}
+ else if (QIcon::hasThemeIcon("gtk-close"))
+ {
+ ui->cmdClose->setIcon(QIcon::fromTheme("gtk-close"));
+ }
+
+ // Set Icon for Export Button
+ if (QIcon::hasThemeIcon("document-export"))
+ {
+ ui->cmdCopy->setIcon(QIcon::fromTheme("document-export"));
+ }
refreshWindowSize();
}
diff --git a/SnapmaticWidget.cpp b/SnapmaticWidget.cpp
index d9fa875..d7fdcca 100644
--- a/SnapmaticWidget.cpp
+++ b/SnapmaticWidget.cpp
@@ -285,12 +285,18 @@ bool SnapmaticWidget::makePictureVisible()
void SnapmaticWidget::makePictureHiddenSlot()
{
- makePictureHidden();
+ if (!makePictureHidden())
+ {
+ QMessageBox::warning(this, QApplication::translate("UserInterface", "Hide In-game"), QApplication::translate("SnapmaticWidget", "Failed to hide %1 In-game from your Snapmatic pictures").arg("\""+smpic->getPictureStr()+"\""));
+ }
}
void SnapmaticWidget::makePictureVisibleSlot()
{
- makePictureVisible();
+ if (!makePictureVisible())
+ {
+ QMessageBox::warning(this, QApplication::translate("UserInterface", "Show In-game"), QApplication::translate("SnapmaticWidget", "Failed to show %1 In-game from your Snapmatic pictures").arg("\""+smpic->getPictureStr()+"\""));
+ }
}
void SnapmaticWidget::editSnapmaticProperties()
diff --git a/UserInterface.ui b/UserInterface.ui
index 151a728..7927dcc 100644
--- a/UserInterface.ui
+++ b/UserInterface.ui
@@ -171,7 +171,7 @@
0
0
625
- 21
+ 23
diff --git a/UserInterface.cpp b/UserInterface.cpp
index 5948176..7c30b99 100644
--- a/UserInterface.cpp
+++ b/UserInterface.cpp
@@ -83,6 +83,40 @@ UserInterface::UserInterface(ProfileDatabase *profileDB, CrewDatabase *crewDB, D
ui->cmdReload->setIcon(QIcon::fromTheme("reload"));
}
+ // Set Icon for Choose GTA V Folder Menu Item
+ if (QIcon::hasThemeIcon("document-open-folder"))
+ {
+ ui->actionSelect_GTA_Folder->setIcon(QIcon::fromTheme("document-open-folder"));
+ }
+ else if (QIcon::hasThemeIcon("gtk-directory"))
+ {
+ ui->actionSelect_GTA_Folder->setIcon(QIcon::fromTheme("gtk-directory"));
+ }
+
+ // Set Icon for Open File Menu Item
+ if (QIcon::hasThemeIcon("document-open"))
+ {
+ ui->actionOpen_File->setIcon(QIcon::fromTheme("document-open"));
+ }
+
+ // Set Icon for Close Profile Menu Item
+ if (QIcon::hasThemeIcon("dialog-close"))
+ {
+ ui->actionSelect_profile->setIcon(QIcon::fromTheme("dialog-close"));
+ }
+ else if (QIcon::hasThemeIcon("gtk-close"))
+ {
+ ui->actionSelect_profile->setIcon(QIcon::fromTheme("gtk-close"));
+ }
+
+ // Set Icon for Exit Menu Item
+ if (QIcon::hasThemeIcon("application-exit"))
+ {
+#ifndef Q_OS_MACOS // Setting icon for exit/quit lead to a crash in Mac OS X
+ ui->actionExit->setIcon(QIcon::fromTheme("application-exit"));
+#endif
+ }
+
// Set Icon for Preferences Menu Item
if (QIcon::hasThemeIcon("preferences-system"))
{
@@ -97,12 +131,22 @@ UserInterface::UserInterface(ProfileDatabase *profileDB, CrewDatabase *crewDB, D
#endif
}
- // Set Icon for Exit Menu Item
- if (QIcon::hasThemeIcon("application-exit"))
+ // Set Icon for Profile Import Menu Item
+ if (QIcon::hasThemeIcon("document-import"))
{
-#ifndef Q_OS_MACOS // Setting icon for exit/quit lead to a crash in Mac OS X
- ui->actionExit->setIcon(QIcon::fromTheme("application-exit"));
-#endif
+ ui->action_Import->setIcon(QIcon::fromTheme("document-import"));
+ }
+
+ // Set Icon for Profile Export Menu Item
+ if (QIcon::hasThemeIcon("document-export"))
+ {
+ ui->actionExport_selected->setIcon(QIcon::fromTheme("document-export"));
+ }
+
+ // Set Icon for Profile Remove Menu Item
+ if (QIcon::hasThemeIcon("remove"))
+ {
+ ui->actionDelete_selected->setIcon(QIcon::fromTheme("remove"));
}
// DPI calculation